PcanBaud class

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

baud1M → const int
baud5K → const int
baud10K → const int
baud20K → const int
baud33K → const int
baud47K → const int
baud50K → const int
baud83K → const int
baud95K → const int
baud100K → const int
baud125K → const int
baud250K → const int
baud500K → const int
baud800K → const int