PcanBindings class

Constructors

PcanBindings(DynamicLibrary _lib)
PcanBindings.load({String? overridePath})
Resolve PCANBasic.dll (or the platform-equivalent shared library) using the standard search path. Pass overridePath to load from a non-default location (typical for CI / dev where the driver was installed under a custom prefix).
factory

Properties

canGetStatus int Function(int channel)
latefinal
canInitialize int Function(int channel, int btr0btr1, int hwType, int ioPort, int interrupt)
latefinal
canRead int Function(int channel, Pointer<TpcanMsg> msg, Pointer<TpcanTimestamp> ts)
latefinal
canReadFd int Function(int channel, Pointer<TpcanMsgFd> msg, Pointer<TpcanTimestamp> ts)
latefinal
canReset int Function(int channel)
latefinal
canUninitialize int Function(int channel)
latefinal
canWrite int Function(int channel, Pointer<TpcanMsg> msg)
latefinal
canWriteFd int Function(int channel, Pointer<TpcanMsgFd> msg)
latefinal
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited