PcanHandle class

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

none → const int
PCAN_NONEBUS.
pciBus1 → const int
PCAN_PCIBUS1.
pciBus2 → const int
pciBus3 → const int
pciBus4 → const int
usbBus1 → const int
PCAN_USBBUS1.
usbBus2 → const int
usbBus3 → const int
usbBus4 → const int
usbBus5 → const int
usbBus6 → const int
usbBus7 → const int
usbBus8 → const int