PcanMsgType class
Properties
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
toString()
→ String
-
A string representation of this object.
inherited
Constants
-
brs
→ const int
-
PCAN_MESSAGE_BRS — bit-rate switch (CAN-FD).
-
echo
→ const int
-
PCAN_MESSAGE_ECHO — echoed (sent by self).
-
errFrame
→ const int
-
PCAN_MESSAGE_ERRFRAME — error frame.
-
esi
→ const int
-
PCAN_MESSAGE_ESI — error-state indicator (CAN-FD).
-
extended
→ const int
-
PCAN_MESSAGE_EXTENDED — 29-bit identifier.
-
fd
→ const int
-
PCAN_MESSAGE_FD — CAN-FD frame.
-
rtr
→ const int
-
PCAN_MESSAGE_RTR — remote transmission request.
-
standard
→ const int
-
PCAN_MESSAGE_STANDARD — 11-bit identifier.
-
status
→ const int
-
PCAN_MESSAGE_STATUS — status frame.