TpcanTimestamp class final

TPCANTimestamp — receive timestamp. 8 bytes packed.

Inheritance
Implemented types
Available extensions

Constructors

TpcanTimestamp()

Properties

address Pointer<T>

Available on T, provided by the StructAddress extension

The memory address of the underlying data.
no setter
hashCode int
The hash code for this object.
no setterinherited
micros int
Microsecond offset within the millisecond (0..999).
getter/setter pair
millis int
Milliseconds since epoch (low 32 bits).
getter/setter pair
millisOverflow int
Overflow counter (15-bit).
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited