VectorXlBindings class
Properties
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
-
xlActivateChannel
↔ int Function(int portHandle, int accessMask, int busType, int flags)
-
latefinal
-
xlCanSetChannelBitrate
↔ int Function(int portHandle, int accessMask, int bitrate)
-
latefinal
-
xlCanTransmit
↔ int Function(int portHandle, int accessMask, Pointer<Uint32> messageCount, Pointer<VectorXlEvent> messageList)
-
latefinal
-
xlCloseDriver
↔ int Function()
-
latefinal
-
xlClosePort
↔ int Function(int portHandle)
-
latefinal
-
xlDeactivateChannel
↔ int Function(int portHandle, int accessMask)
-
latefinal
-
xlGetChannelMask
↔ int Function(Pointer<Uint64> channelMask)
-
latefinal
-
xlOpenDriver
↔ int Function()
-
latefinal
-
xlOpenPort
↔ int Function(Pointer<Int32> portHandle, Pointer<Uint8> userName, int accessMask, Pointer<Uint64> permissionMask, int rxQueueSize, int xlInterfaceVersion, int busType)
-
latefinal
-
xlReceive
↔ int Function(int portHandle, Pointer<Uint32> eventCount, Pointer<VectorXlEvent> eventList)
-
latefinal
Methods
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
toString()
→ String
-
A string representation of this object.
inherited