VectorXlCanMsgFlag class

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

errorFrame → const int
XL_CAN_MSG_FLAG_ERROR_FRAME.
nerr → const int
XL_CAN_MSG_FLAG_NERR.
overrun → const int
XL_CAN_MSG_FLAG_OVERRUN.
remoteFrame → const int
XL_CAN_MSG_FLAG_REMOTE_FRAME — RTR.
reserved1 → const int
XL_CAN_MSG_FLAG_RESERVED_1.
srrBitDom → const int
XL_CAN_MSG_FLAG_SRR_BIT_DOM (CAN extended SRR bit dominant).
txCompleted → const int
XL_CAN_MSG_FLAG_TX_COMPLETED — TX confirmation.
txRequest → const int
XL_CAN_MSG_FLAG_TX_REQUEST — TX request acknowledgement.
wakeup → const int
XL_CAN_MSG_FLAG_WAKEUP.