canMsg property
Union slot. We project VectorXlCanMsg (32 bytes) over it. Casters that need other event types reinterpret these bytes.
Implementation
external VectorXlCanMsg canMsg;
Union slot. We project VectorXlCanMsg (32 bytes) over it. Casters that need other event types reinterpret these bytes.
external VectorXlCanMsg canMsg;