PcanBindings class
Constructors
PcanBindings (DynamicLibrary _lib )
PcanBindings.load ({String ? overridePath })
Resolve PCANBasic.dll (or the platform-equivalent shared
library) using the standard search path. Pass overridePath to
load from a non-default location (typical for CI / dev where the
driver was installed under a custom prefix).
factory
Properties
canGetStatus
↔ int Function(int channel )
late final
canInitialize
↔ int Function(int channel , int btr0btr1 , int hwType , int ioPort , int interrupt )
late final
canRead
↔ int Function(int channel , Pointer <TpcanMsg > msg , Pointer <TpcanTimestamp > ts )
late final
canReadFd
↔ int Function(int channel , Pointer <TpcanMsgFd > msg , Pointer <TpcanTimestamp > ts )
late final
canReset
↔ int Function(int channel )
late final
canUninitialize
↔ int Function(int channel )
late final
canWrite
↔ int Function(int channel , Pointer <TpcanMsg > msg )
late final
canWriteFd
↔ int Function(int channel , Pointer <TpcanMsgFd > msg )
late final
hashCode
→ int
The hash code for this object.
no setter inherited
runtimeType
→ Type
A representation of the runtime type of the object.
no setter inherited
Methods
noSuchMethod (Invocation invocation )
→ dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString ()
→ String
A string representation of this object.
inherited