PcanStatus class
Properties
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
toString()
→ String
-
A string representation of this object.
inherited
Constants
-
busHeavy
→ const int
-
PCAN_ERROR_BUSHEAVY / BUSWARNING — error counter ≥ heavy.
-
busLight
→ const int
-
PCAN_ERROR_BUSLIGHT — bus error: an error counter ≥ warning.
-
busOff
→ const int
-
PCAN_ERROR_BUSOFF — bus off (controller reset required).
-
busPassive
→ const int
-
PCAN_ERROR_BUSPASSIVE — bus passive (peers stopped ACKing).
-
illOperation
→ const int
-
PCAN_ERROR_ILLOPERATION — operation invalid in current state.
-
notInitialized
→ const int
-
PCAN_ERROR_INITIALIZE — channel not initialized.
-
ok
→ const int
-
PCAN_ERROR_OK — operation succeeded.
-
overrun
→ const int
-
PCAN_ERROR_OVERRUN — receive queue overrun.
-
qrcvEmpty
→ const int
-
PCAN_ERROR_QRCVEMPTY — receive queue empty (poll returns this
when there is nothing waiting).
-
qxmtFull
→ const int
-
PCAN_ERROR_QXMTFULL — transmit queue full.
-
xmtFull
→ const int
-
PCAN_ERROR_XMTFULL — transmit buffer full.