SocketCanBindings class

Constructors

SocketCanBindings(DynamicLibrary libc)
SocketCanBindings.fromProcess()
Open libc — on Linux glibc/musl this is the process's already-loaded libc, so DynamicLibrary.process is the canonical handle. Override only for tests / sandbox environments.
factory

Properties

bind BindDart
final
closeFd CloseDart
final
hashCode int
The hash code for this object.
no setterinherited
ioctl IoctlDart
final
read ReadWriteDart
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
setsockopt SetsockoptDart
final
socket SocketDart
final
write ReadWriteDart
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited