VectorXlBusType class
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- a429 → const int
-
XL_BUS_TYPE_A429. - can → const int
-
XL_BUS_TYPE_CAN. - daio → const int
-
XL_BUS_TYPE_DAIO. - ethernet → const int
-
XL_BUS_TYPE_ETHERNET. - flexRay → const int
-
XL_BUS_TYPE_FLEXRAY. - j1708 → const int
-
XL_BUS_TYPE_J1708. - kLine → const int
-
XL_BUS_TYPE_KLINE. - lin → const int
-
XL_BUS_TYPE_LIN. - most → const int
-
XL_BUS_TYPE_MOST.