VectorXlEvent class final
XLevent legacy struct — 48 bytes.
Layout (vxlapi.h):
- 8-byte header :
tag(1) chanIndex(1) transId(2) portHandle(2) flags(1) reserved(1) - 8-byte :
timeStamp(XLuint64) - 32-byte :
tagDataunion (we model the canMsg arm)
- Inheritance
- Implemented types
- Available extensions
Constructors
Properties
-
address
→ Pointer<
T> -
Available on T, provided by the StructAddress extension
The memory address of the underlying data.no setter - canMsg ↔ VectorXlCanMsg
-
Union slot. We project VectorXlCanMsg (32 bytes) over it.
Casters that need other event types reinterpret these bytes.
getter/setter pair
- chanIndex ↔ int
-
getter/setter pair
- flags ↔ int
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- portHandle ↔ int
-
getter/setter pair
- reserved ↔ int
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- tag ↔ int
-
getter/setter pair
- timeStamp ↔ int
-
getter/setter pair
- transId ↔ int
-
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited