VectorXlEventTag class
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- chipState → const int
-
XL_CHIP_STATE. - receiveMsg → const int
-
XL_RECEIVE_MSG— CAN receive (RX) or transmit-confirm (TX). - timerEvent → const int
-
XL_TIMER_EVENT. - transceiverInfo → const int
-
XL_TRANSCEIVER_INFO. - transmitMsg → const int
-
XL_TRANSMIT_MSG— used when transmitting (we set this tag).