VectorXlStatus class

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

hwNotPresent → const int
XL_ERR_HW_NOT_PRESENT.
invalidChannelMask → const int
XL_ERR_INVALID_CHANNEL_MASK — channel not present.
noLicense → const int
XL_ERR_NO_LICENSE — requested channel not licensed.
pending → const int
XL_PENDING — operation deferred (often expected for receive).
queueIsEmpty → const int
XL_ERR_QUEUE_IS_EMPTY.
queueIsFull → const int
XL_ERR_QUEUE_IS_FULL.
success → const int
XL_SUCCESS.
txNotPossible → const int
XL_ERR_TX_NOT_POSSIBLE.
wrongParameter → const int
XL_ERR_WRONG_PARAMETER.